=============================
:code:`Trakt['sync/history']`
=============================

.. automodule:: trakt.interfaces.sync.history

  .. autoclass:: SyncHistoryInterface
    :members: add, flags, get, movies, remove, shows
    :undoc-members:
